@@ -1,17 +1,16 @@
 from django import forms
 from django.conf import settings
-from django.conf.urls import url
-from django.contrib import admin
-from django.contrib import messages
+from django.contrib import admin, messages
 from django.contrib.admin import helpers
 from django.contrib.sites.models import Site
 from django.http import HttpResponseRedirect
 from django.shortcuts import render
-from django.utils.translation import ungettext, ugettext_lazy as _
+from django.urls import path
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ungettext
 
 from .forms import UploadZipForm
-from .models import Gallery, Photo, PhotoEffect, PhotoSize, \
-    Watermark
+from .models import Gallery, Photo, PhotoEffect, PhotoSize, Watermark
 
 MULTISITE = getattr(settings, 'PHOTOLOGUE_MULTISITE', False)
 
@@ -47,14 +46,14 @@ class GalleryAdmin(admin.ModelAdmin):
         """ Set the current site as initial value. """
         if db_field.name == "sites":
             kwargs["initial"] = [Site.objects.get_current()]
-        return super(GalleryAdmin, self).formfield_for_manytomany(db_field, request, **kwargs)
+        return super().formfield_for_manytomany(db_field, request, **kwargs)
 
     def save_related(self, request, form, *args, **kwargs):
         """
         If the user has saved a gallery with a photo that belongs only to
         different Sites - it might cause much confusion. So let them know.
         """
-        super(GalleryAdmin, self).save_related(request, form, *args, **kwargs)
+        super().save_related(request, form, *args, **kwargs)
         orphaned_photos = form.instance.orphaned_photos()
         if orphaned_photos:
             msg = ungettext(
@@ -101,7 +100,7 @@ class GalleryAdmin(admin.ModelAdmin):
             'All photos in galleries %(galleries)s have been successfully added to %(site)s',
             len(queryset)
         ) % {'site': current_site.name,
-             'galleries': ", ".join(["'{0}'".format(gallery.title) for gallery in queryset])}
+             'galleries': ", ".join(["'{}'".format(gallery.title) for gallery in queryset])}
         messages.success(request, msg)
 
     add_photos_to_current_site.short_description = \
@@ -116,7 +115,7 @@ class GalleryAdmin(admin.ModelAdmin):
             'All photos in galleries %(galleries)s have been successfully removed from %(site)s',
             len(queryset)
         ) % {'site': current_site.name,
-             'galleries': ", ".join(["'{0}'".format(gallery.title) for gallery in queryset])}
+             'galleries': ", ".join(["'{}'".format(gallery.title) for gallery in queryset])}
         messages.success(request, msg)
 
     remove_photos_from_current_site.short_description = \
@@ -155,7 +154,7 @@ class PhotoAdmin(admin.ModelAdmin):
         """ Set the current site as initial value. """
         if db_field.name == "sites":
             kwargs["initial"] = [Site.objects.get_current()]
-        return super(PhotoAdmin, self).formfield_for_manytomany(db_field, request, **kwargs)
+        return super().formfield_for_manytomany(db_field, request, **kwargs)
 
     def add_photos_to_current_site(modeladmin, request, queryset):
         current_site = Site.objects.get_current()
@@ -184,11 +183,11 @@ class PhotoAdmin(admin.ModelAdmin):
         _("Remove selected photos from the current site")
 
     def get_urls(self):
-        urls = super(PhotoAdmin, self).get_urls()
+        urls = super().get_urls()
         custom_urls = [
-            url(r'^upload_zip/$',
-                self.admin_site.admin_view(self.upload_zip),
-                name='photologue_upload_zip')
+            path('upload_zip/',
+                 self.admin_site.admin_view(self.upload_zip),
+                 name='photologue_upload_zip')
         ]
         return custom_urls + urls
 
